/***************************************************************************
*                                                                          *
*   test.c:         Test program for basic operation of the driver.        *
*                   This program opens the device, resets the camera,      *
*                   sends some setup parameters and aquires an image which *
*                   can be found in the binary file "test.bin" (raw        *
*                   series of 16 bit pixel values).                        *
*                                                                          *
*                   Please look at /var/log/messages for program output    *
*                   as no status feedback functions are currently          *
*                   available.                                             *
*                                                                          *
*   Author:         Robert Schwebel (robert@schwebel.de)                   *
*                                                                          *
*   Revision:       0.0.1 (RS, 19.09.1999)                                 *
*                                                                          *
****************************************************************************

#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>

#include "lcccd14.h"

main(int argc, char argv[]) {

  int  handle;
  int  result;
  long bytes = 0;
  unsigned char buffer[2048];
  int  i;
  char outbyte;
  FILE *fp;

  printf("\nLcCCD14 test program");
  printf("   (c) 1999 Robert Schwebel (robert@schwebel.de)\n\n");

  /* open device */
  printf("Trying to open /dev/lcccd14...\n");
  handle = open("/dev/lcccd14",O_RDWR);
  if (handle<0) {
    printf("... got no valid handle!\n");
    return(-1);
  }
  printf("...got handle: %d\n",handle);

  for (i=0;;i=1){}

  /* reset */
  printf("Resetting camera...\n");
  result = ioctl(handle,Lc_RESET);
  printf("...result: %d\n",result);
  if (result != 0) {
    printf("Reset not successful!\n");
    return(-1);
  }
  

  /* initialize parameters */
  result = ioctl(handle,Lc_SET_INTTIME,10);
  result = ioctl(handle,Lc_SET_TEMP,   35);
  result = ioctl(handle,Lc_SET_COOLING, 0);
  result = ioctl(handle,Lc_SET_RES,     0);
  result = ioctl(handle,Lc_SET_BIN,     0);
  result = ioctl(handle,Lc_SET_SAMP,    1);
  result = ioctl(handle,Lc_SET_INTER,   1);
  result = ioctl(handle,Lc_SETUP);
 
  /* readout parameters */
  printf("Writing parameters to syslog...\n");
  result = ioctl(handle,Lc_PRINT_PARAMS);
  printf("...done.\n");

  /* integrate */
  printf("Integrating...\n");
  result = ioctl(handle,Lc_INTEGRATE);
  printf("...done\n");

  /* readout data */
  printf("Opening outfile: \n");
  fp = fopen("test.bin","w");
  if (fp==NULL) {
    printf("Couldn't open outfile!\n");
    return(-1);
  } else {
    printf("Outfile is open.\n");
  }
  
  printf("Reading data: \n");

  do {
    result = read(handle,&buffer[0],1024);
    
    if (result>0) {
/*
      printf("Writing %d Bytes...\n",result); 
*/
      bytes+=result;
      for (i=0; i<result; i++) { 
        putc(buffer[i],fp); 
      }        
    }
/*
    
*/    
  } while (result > 0);
  
  printf("...\n%d bytes read.\n",bytes);
  printf("Closing outfile\n");
  close(fp);
  
  /* close */
  printf("Closing camera...\n");
  close(handle);
  printf("...done\n\n");

}
